#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class IdentityDescription :
    def __init__( self):
        self.mbox = None
        self.id = None
        self.email = None
        self.name = None
        self.isDefault = None
        self.displayname = None
        self.signature = None
        self.mboxName = None
        pass

class __IdentityDescriptionSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = IdentityDescription()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        mboxValue = value['mbox']
        instance.mbox = serder.STRING.parse(mboxValue)
        idValue = value['id']
        instance.id = serder.STRING.parse(idValue)
        emailValue = value['email']
        instance.email = serder.STRING.parse(emailValue)
        nameValue = value['name']
        instance.name = serder.STRING.parse(nameValue)
        isDefaultValue = value['isDefault']
        instance.isDefault = serder.BOOLEAN.parse(isDefaultValue)
        displaynameValue = value['displayname']
        instance.displayname = serder.STRING.parse(displaynameValue)
        signatureValue = value['signature']
        instance.signature = serder.STRING.parse(signatureValue)
        mboxNameValue = value['mboxName']
        instance.mboxName = serder.STRING.parse(mboxNameValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        mboxValue = value.mbox
        instance["mbox"] = serder.STRING.encode(mboxValue)
        idValue = value.id
        instance["id"] = serder.STRING.encode(idValue)
        emailValue = value.email
        instance["email"] = serder.STRING.encode(emailValue)
        nameValue = value.name
        instance["name"] = serder.STRING.encode(nameValue)
        isDefaultValue = value.isDefault
        instance["isDefault"] = serder.BOOLEAN.encode(isDefaultValue)
        displaynameValue = value.displayname
        instance["displayname"] = serder.STRING.encode(displaynameValue)
        signatureValue = value.signature
        instance["signature"] = serder.STRING.encode(signatureValue)
        mboxNameValue = value.mboxName
        instance["mboxName"] = serder.STRING.encode(mboxNameValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class SubscriptionInformations :
    def __init__( self):
        self.version = None
        self.installationVersion = None
        self.customer = None
        self.customerCode = None
        self.dealer = None
        self.distributor = None
        self.kind = None
        self.starts = None
        self.ends = None
        self.valid = None
        self.pubKeyFingerprint = None
        self.validProvider = None
        self.fromTechVersion = None
        self.indicator = None
        self.contacts = None
        self.messages = None
        pass

class __SubscriptionInformationsSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = SubscriptionInformations()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        versionValue = value['version']
        instance.version = serder.STRING.parse(versionValue)
        installationVersionValue = value['installationVersion']
        instance.installationVersion = serder.STRING.parse(installationVersionValue)
        customerValue = value['customer']
        instance.customer = serder.STRING.parse(customerValue)
        customerCodeValue = value['customerCode']
        instance.customerCode = serder.STRING.parse(customerCodeValue)
        dealerValue = value['dealer']
        instance.dealer = serder.STRING.parse(dealerValue)
        distributorValue = value['distributor']
        instance.distributor = serder.STRING.parse(distributorValue)
        from netbluemind.system.api.SubscriptionInformationsKind import SubscriptionInformationsKind
        from netbluemind.system.api.SubscriptionInformationsKind import __SubscriptionInformationsKindSerDer__
        kindValue = value['kind']
        instance.kind = __SubscriptionInformationsKindSerDer__().parse(kindValue)
        startsValue = value['starts']
        instance.starts = serder.DATE.parse(startsValue)
        endsValue = value['ends']
        instance.ends = serder.DATE.parse(endsValue)
        validValue = value['valid']
        instance.valid = serder.BOOLEAN.parse(validValue)
        pubKeyFingerprintValue = value['pubKeyFingerprint']
        instance.pubKeyFingerprint = serder.STRING.parse(pubKeyFingerprintValue)
        validProviderValue = value['validProvider']
        instance.validProvider = serder.BOOLEAN.parse(validProviderValue)
        fromTechVersionValue = value['fromTechVersion']
        instance.fromTechVersion = serder.STRING.parse(fromTechVersionValue)
        from netbluemind.system.api.SubscriptionInformationsInstallationIndicator import SubscriptionInformationsInstallationIndicator
        from netbluemind.system.api.SubscriptionInformationsInstallationIndicator import __SubscriptionInformationsInstallationIndicatorSerDer__
        indicatorValue = value['indicator']
        instance.indicator = serder.ListSerDer(__SubscriptionInformationsInstallationIndicatorSerDer__()).parse(indicatorValue)
        contactsValue = value['contacts']
        instance.contacts = serder.ListSerDer(serder.STRING).parse(contactsValue)
        from netbluemind.system.api.SubscriptionInformationsMessage import SubscriptionInformationsMessage
        from netbluemind.system.api.SubscriptionInformationsMessage import __SubscriptionInformationsMessageSerDer__
        messagesValue = value['messages']
        instance.messages = serder.ListSerDer(__SubscriptionInformationsMessageSerDer__()).parse(messagesValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        versionValue = value.version
        instance["version"] = serder.STRING.encode(versionValue)
        installationVersionValue = value.installationVersion
        instance["installationVersion"] = serder.STRING.encode(installationVersionValue)
        customerValue = value.customer
        instance["customer"] = serder.STRING.encode(customerValue)
        customerCodeValue = value.customerCode
        instance["customerCode"] = serder.STRING.encode(customerCodeValue)
        dealerValue = value.dealer
        instance["dealer"] = serder.STRING.encode(dealerValue)
        distributorValue = value.distributor
        instance["distributor"] = serder.STRING.encode(distributorValue)
        from netbluemind.system.api.SubscriptionInformationsKind import SubscriptionInformationsKind
        from netbluemind.system.api.SubscriptionInformationsKind import __SubscriptionInformationsKindSerDer__
        kindValue = value.kind
        instance["kind"] = __SubscriptionInformationsKindSerDer__().encode(kindValue)
        startsValue = value.starts
        instance["starts"] = serder.DATE.encode(startsValue)
        endsValue = value.ends
        instance["ends"] = serder.DATE.encode(endsValue)
        validValue = value.valid
        instance["valid"] = serder.BOOLEAN.encode(validValue)
        pubKeyFingerprintValue = value.pubKeyFingerprint
        instance["pubKeyFingerprint"] = serder.STRING.encode(pubKeyFingerprintValue)
        validProviderValue = value.validProvider
        instance["validProvider"] = serder.BOOLEAN.encode(validProviderValue)
        fromTechVersionValue = value.fromTechVersion
        instance["fromTechVersion"] = serder.STRING.encode(fromTechVersionValue)
        from netbluemind.system.api.SubscriptionInformationsInstallationIndicator import SubscriptionInformationsInstallationIndicator
        from netbluemind.system.api.SubscriptionInformationsInstallationIndicator import __SubscriptionInformationsInstallationIndicatorSerDer__
        indicatorValue = value.indicator
        instance["indicator"] = serder.ListSerDer(__SubscriptionInformationsInstallationIndicatorSerDer__()).encode(indicatorValue)
        contactsValue = value.contacts
        instance["contacts"] = serder.ListSerDer(serder.STRING).encode(contactsValue)
        from netbluemind.system.api.SubscriptionInformationsMessage import SubscriptionInformationsMessage
        from netbluemind.system.api.SubscriptionInformationsMessage import __SubscriptionInformationsMessageSerDer__
        messagesValue = value.messages
        instance["messages"] = serder.ListSerDer(__SubscriptionInformationsMessageSerDer__()).encode(messagesValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IOrgUnits_VERSION = "4.1.57000"

class IOrgUnits(BaseEndpoint):
    def __init__(self, apiKey, url ,domain ):
        self.url = url
        self.apiKey = apiKey
        self.base = url +'/directory/_ou/{domain}'
        self.domain_ = domain
        self.base = self.base.replace('{domain}',domain)

    def getAdministratorRoles (self, uid , dirUid , groups ):
        postUri = "/{uid}/{dirUid}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        postUri = postUri.replace("{dirUid}",dirUid);
        __data__ = serder.ListSerDer(serder.STRING).encode(groups)
        __encoded__ = json.dumps(__data__)
        queryParams = {     };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IOrgUnits_VERSION}, data = __encoded__);
        return self.handleResult__(serder.SetSerDer(serder.STRING), response)
    def setAdministratorRoles (self, uid , dirUid , roles ):
        postUri = "/{uid}/{dirUid}/_set";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        postUri = postUri.replace("{dirUid}",dirUid);
        __data__ = serder.SetSerDer(serder.STRING).encode(roles)
        __encoded__ = json.dumps(__data__)
        queryParams = {     };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IOrgUnits_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def update (self, uid , value ):
        postUri = "/{uid}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        from netbluemind.directory.api.OrgUnit import OrgUnit
        from netbluemind.directory.api.OrgUnit import __OrgUnitSerDer__
        __data__ = __OrgUnitSerDer__().encode(value)
        __encoded__ = json.dumps(__data__)
        queryParams = {    };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IOrgUnits_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def removeAdministrator (self, administrator ):
        postUri = "/_deleteadmin";
        __data__ = None
        __encoded__ = None
        queryParams = {  'administrator': administrator   };

        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IOrgUnits_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def getAdministrators (self, uid ):
        postUri = "/{uid}/_administrators";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IOrgUnits_VERSION}, data = __encoded__);
        return self.handleResult__(serder.SetSerDer(serder.STRING), response)
    def delete (self, uid ):
        postUri = "/{uid}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IOrgUnits_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def getComplete (self, uid ):
        postUri = "/{uid}/complete";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IOrgUnits_VERSION}, data = __encoded__);
        from netbluemind.directory.api.OrgUnit import OrgUnit
        from netbluemind.directory.api.OrgUnit import __OrgUnitSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(__ItemValueSerDer__(__OrgUnitSerDer__()), response)
    def getChildren (self, uid ):
        postUri = "/{uid}/_children";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IOrgUnits_VERSION}, data = __encoded__);
        from netbluemind.directory.api.OrgUnit import OrgUnit
        from netbluemind.directory.api.OrgUnit import __OrgUnitSerDer__
        from netbluemind.core.container.model.ItemValue import ItemValue
        from netbluemind.core.container.model.ItemValue import __ItemValueSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemValueSerDer__(__OrgUnitSerDer__())), response)
    def search (self, query ):
        postUri = "/_search";
        __data__ = None
        __encoded__ = None
        from netbluemind.directory.api.OrgUnitQuery import OrgUnitQuery
        from netbluemind.directory.api.OrgUnitQuery import __OrgUnitQuerySerDer__
        __data__ = __OrgUnitQuerySerDer__().encode(query)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IOrgUnits_VERSION}, data = __encoded__);
        from netbluemind.directory.api.OrgUnitPath import OrgUnitPath
        from netbluemind.directory.api.OrgUnitPath import __OrgUnitPathSerDer__
        return self.handleResult__(serder.ListSerDer(__OrgUnitPathSerDer__()), response)
    def getPath (self, uid ):
        postUri = "/{uid}/path";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IOrgUnits_VERSION}, data = __encoded__);
        from netbluemind.directory.api.OrgUnitPath import OrgUnitPath
        from netbluemind.directory.api.OrgUnitPath import __OrgUnitPathSerDer__
        return self.handleResult__(__OrgUnitPathSerDer__(), response)
    def create (self, uid , value ):
        postUri = "/{uid}";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{uid}",uid);
        from netbluemind.directory.api.OrgUnit import OrgUnit
        from netbluemind.directory.api.OrgUnit import __OrgUnitSerDer__
        __data__ = __OrgUnitSerDer__().encode(value)
        __encoded__ = json.dumps(__data__)
        queryParams = {    };

        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IOrgUnits_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def listByAdministrator (self, administrator , groups ):
        postUri = "/_byAdmin";
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.STRING).encode(groups)
        __encoded__ = json.dumps(__data__)
        queryParams = {  'administrator': administrator    };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IOrgUnits_VERSION}, data = __encoded__);
        from netbluemind.directory.api.OrgUnitPath import OrgUnitPath
        from netbluemind.directory.api.OrgUnitPath import __OrgUnitPathSerDer__
        return self.handleResult__(serder.ListSerDer(__OrgUnitPathSerDer__()), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

from netbluemind.core.container.model.BaseContainerDescriptor import BaseContainerDescriptor
from netbluemind.core.container.model.BaseContainerDescriptor import __BaseContainerDescriptorSerDer__
class ContainerDescriptor (BaseContainerDescriptor):
    def __init__( self):
        BaseContainerDescriptor.__init__(self)
        self.writable = None
        self.verbs = None
        self.offlineSync = None
        self.internalId = None
        pass

class __ContainerDescriptorSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = ContainerDescriptor()
        __BaseContainerDescriptorSerDer__().parseInternal(value,instance)

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        writableValue = value['writable']
        instance.writable = serder.BOOLEAN.parse(writableValue)
        from netbluemind.core.container.model.acl.Verb import Verb
        from netbluemind.core.container.model.acl.Verb import __VerbSerDer__
        verbsValue = value['verbs']
        instance.verbs = serder.SetSerDer(__VerbSerDer__()).parse(verbsValue)
        offlineSyncValue = value['offlineSync']
        instance.offlineSync = serder.BOOLEAN.parse(offlineSyncValue)
        internalIdValue = value['internalId']
        instance.internalId = serder.LONG.parse(internalIdValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):
        __BaseContainerDescriptorSerDer__().encodeInternal(value,instance)

        writableValue = value.writable
        instance["writable"] = serder.BOOLEAN.encode(writableValue)
        from netbluemind.core.container.model.acl.Verb import Verb
        from netbluemind.core.container.model.acl.Verb import __VerbSerDer__
        verbsValue = value.verbs
        instance["verbs"] = serder.SetSerDer(__VerbSerDer__()).encode(verbsValue)
        offlineSyncValue = value.offlineSync
        instance["offlineSync"] = serder.BOOLEAN.encode(offlineSyncValue)
        internalIdValue = value.internalId
        instance["internalId"] = serder.LONG.encode(internalIdValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class VCardOrganizational :
    def __init__( self):
        self.title = None
        self.role = None
        self.org = None
        self.member = None
        pass

class __VCardOrganizationalSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = VCardOrganizational()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        titleValue = value['title']
        instance.title = serder.STRING.parse(titleValue)
        roleValue = value['role']
        instance.role = serder.STRING.parse(roleValue)
        from netbluemind.addressbook.api.VCardOrganizationalOrg import VCardOrganizationalOrg
        from netbluemind.addressbook.api.VCardOrganizationalOrg import __VCardOrganizationalOrgSerDer__
        orgValue = value['org']
        instance.org = __VCardOrganizationalOrgSerDer__().parse(orgValue)
        from netbluemind.addressbook.api.VCardOrganizationalMember import VCardOrganizationalMember
        from netbluemind.addressbook.api.VCardOrganizationalMember import __VCardOrganizationalMemberSerDer__
        memberValue = value['member']
        instance.member = serder.ListSerDer(__VCardOrganizationalMemberSerDer__()).parse(memberValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        titleValue = value.title
        instance["title"] = serder.STRING.encode(titleValue)
        roleValue = value.role
        instance["role"] = serder.STRING.encode(roleValue)
        from netbluemind.addressbook.api.VCardOrganizationalOrg import VCardOrganizationalOrg
        from netbluemind.addressbook.api.VCardOrganizationalOrg import __VCardOrganizationalOrgSerDer__
        orgValue = value.org
        instance["org"] = __VCardOrganizationalOrgSerDer__().encode(orgValue)
        from netbluemind.addressbook.api.VCardOrganizationalMember import VCardOrganizationalMember
        from netbluemind.addressbook.api.VCardOrganizationalMember import __VCardOrganizationalMemberSerDer__
        memberValue = value.member
        instance["member"] = serder.ListSerDer(__VCardOrganizationalMemberSerDer__()).encode(memberValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

from netbluemind.core.container.api.ContainerSubscription import ContainerSubscription
from netbluemind.core.container.api.ContainerSubscription import __ContainerSubscriptionSerDer__
class ContainerSubscriptionModel (ContainerSubscription):
    def __init__( self):
        ContainerSubscription.__init__(self)
        self.containerType = None
        self.owner = None
        self.defaultContainer = None
        self.name = None
        pass

class __ContainerSubscriptionModelSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = ContainerSubscriptionModel()
        __ContainerSubscriptionSerDer__().parseInternal(value,instance)

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        containerTypeValue = value['containerType']
        instance.containerType = serder.STRING.parse(containerTypeValue)
        ownerValue = value['owner']
        instance.owner = serder.STRING.parse(ownerValue)
        defaultContainerValue = value['defaultContainer']
        instance.defaultContainer = serder.BOOLEAN.parse(defaultContainerValue)
        nameValue = value['name']
        instance.name = serder.STRING.parse(nameValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):
        __ContainerSubscriptionSerDer__().encodeInternal(value,instance)

        containerTypeValue = value.containerType
        instance["containerType"] = serder.STRING.encode(containerTypeValue)
        ownerValue = value.owner
        instance["owner"] = serder.STRING.encode(ownerValue)
        defaultContainerValue = value.defaultContainer
        instance["defaultContainer"] = serder.BOOLEAN.encode(defaultContainerValue)
        nameValue = value.name
        instance["name"] = serder.STRING.encode(nameValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
import json
from netbluemind.python import serder
from netbluemind.python.client import BaseEndpoint

IContainerManagement_VERSION = "4.1.57000"

class IContainerManagement(BaseEndpoint):
    def __init__(self, apiKey, url ,containerUid ):
        self.url = url
        self.apiKey = apiKey
        self.base = url +'/containers/_manage/{containerUid}'
        self.containerUid_ = containerUid
        self.base = self.base.replace('{containerUid}',containerUid)

    def getDescriptor (self):
        postUri = "/_descriptor";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = __encoded__);
        from netbluemind.core.container.model.ContainerDescriptor import ContainerDescriptor
        from netbluemind.core.container.model.ContainerDescriptor import __ContainerDescriptorSerDer__
        return self.handleResult__(__ContainerDescriptorSerDer__(), response)
    def getSettings (self):
        postUri = "/_settings";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = __encoded__);
        return self.handleResult__(serder.MapSerDer(serder.STRING), response)
    def getAccessControlList (self):
        postUri = "/_acl";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = __encoded__);
        from netbluemind.core.container.model.acl.AccessControlEntry import AccessControlEntry
        from netbluemind.core.container.model.acl.AccessControlEntry import __AccessControlEntrySerDer__
        return self.handleResult__(serder.ListSerDer(__AccessControlEntrySerDer__()), response)
    def getAllItems (self):
        postUri = "/_list";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = __encoded__);
        from netbluemind.core.container.model.ItemDescriptor import ItemDescriptor
        from netbluemind.core.container.model.ItemDescriptor import __ItemDescriptorSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemDescriptorSerDer__()), response)
    def subscribers (self):
        postUri = "/_subscription";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = __encoded__);
        return self.handleResult__(serder.ListSerDer(serder.STRING), response)
    def getItemCount (self):
        postUri = "/_itemCount";
        __data__ = None
        __encoded__ = None
        queryParams = {  };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = __encoded__);
        from netbluemind.core.container.api.Count import Count
        from netbluemind.core.container.api.Count import __CountSerDer__
        return self.handleResult__(__CountSerDer__(), response)
    def setAccessControlList (self, entries ):
        postUri = "/_acl";
        __data__ = None
        __encoded__ = None
        from netbluemind.core.container.model.acl.AccessControlEntry import AccessControlEntry
        from netbluemind.core.container.model.acl.AccessControlEntry import __AccessControlEntrySerDer__
        __data__ = serder.ListSerDer(__AccessControlEntrySerDer__()).encode(entries)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def update (self, descriptor ):
        postUri = "/_descriptor";
        __data__ = None
        __encoded__ = None
        from netbluemind.core.container.model.ContainerModifiableDescriptor import ContainerModifiableDescriptor
        from netbluemind.core.container.model.ContainerModifiableDescriptor import __ContainerModifiableDescriptorSerDer__
        __data__ = __ContainerModifiableDescriptorSerDer__().encode(descriptor)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def allowOfflineSync (self, subject ):
        postUri = "/{subject}/offlineSync";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{subject}",subject);
        queryParams = {   };

        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def setSettings (self, settings ):
        postUri = "/_settings";
        __data__ = None
        __encoded__ = None
        __data__ = serder.MapSerDer(serder.STRING).encode(settings)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def getItems (self, uids ):
        postUri = "/_mget";
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.STRING).encode(uids)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = __encoded__);
        from netbluemind.core.container.model.ItemDescriptor import ItemDescriptor
        from netbluemind.core.container.model.ItemDescriptor import __ItemDescriptorSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemDescriptorSerDer__()), response)
    def disallowOfflineSync (self, subject ):
        postUri = "/{subject}/offlineSync";
        __data__ = None
        __encoded__ = None
        postUri = postUri.replace("{subject}",subject);
        queryParams = {   };

        response = requests.delete( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def canAccess (self, verbsOrRoles ):
        postUri = "/_canAccess";
        __data__ = None
        __encoded__ = None
        __data__ = serder.ListSerDer(serder.STRING).encode(verbsOrRoles)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.post( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = __encoded__);
        return self.handleResult__(serder.BOOLEAN, response)
    def setPersonalSettings (self, settings ):
        postUri = "/_personalSettings";
        __data__ = None
        __encoded__ = None
        __data__ = serder.MapSerDer(serder.STRING).encode(settings)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.put( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = __encoded__);
        return self.handleResult__(None, response)
    def getFilteredItems (self, filter ):
        postUri = "/_filtered";
        __data__ = None
        __encoded__ = None
        from netbluemind.core.container.model.ItemFlagFilter import ItemFlagFilter
        from netbluemind.core.container.model.ItemFlagFilter import __ItemFlagFilterSerDer__
        __data__ = __ItemFlagFilterSerDer__().encode(filter)
        __encoded__ = json.dumps(__data__)
        queryParams = {   };

        response = requests.get( self.base + postUri, params = queryParams, verify=False, headers = {'X-BM-ApiKey' : self.apiKey, 'Accept' : 'application/json', 'X-BM-ClientVersion' : IContainerManagement_VERSION}, data = __encoded__);
        from netbluemind.core.container.model.ItemDescriptor import ItemDescriptor
        from netbluemind.core.container.model.ItemDescriptor import __ItemDescriptorSerDer__
        return self.handleResult__(serder.ListSerDer(__ItemDescriptorSerDer__()), response)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class ChangeLogEntry :
    def __init__( self):
        self.version = None
        self.itemUid = None
        self.itemExtId = None
        self.author = None
        self.type = None
        self.date = None
        self.origin = None
        self.internalId = None
        self.weightSeed = None
        pass

class __ChangeLogEntrySerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = ChangeLogEntry()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        versionValue = value['version']
        instance.version = serder.LONG.parse(versionValue)
        itemUidValue = value['itemUid']
        instance.itemUid = serder.STRING.parse(itemUidValue)
        itemExtIdValue = value['itemExtId']
        instance.itemExtId = serder.STRING.parse(itemExtIdValue)
        authorValue = value['author']
        instance.author = serder.STRING.parse(authorValue)
        from netbluemind.core.container.model.ChangeLogEntryType import ChangeLogEntryType
        from netbluemind.core.container.model.ChangeLogEntryType import __ChangeLogEntryTypeSerDer__
        typeValue = value['type']
        instance.type = __ChangeLogEntryTypeSerDer__().parse(typeValue)
        dateValue = value['date']
        instance.date = serder.DATE.parse(dateValue)
        originValue = value['origin']
        instance.origin = serder.STRING.parse(originValue)
        internalIdValue = value['internalId']
        instance.internalId = serder.LONG.parse(internalIdValue)
        weightSeedValue = value['weightSeed']
        instance.weightSeed = serder.LONG.parse(weightSeedValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        versionValue = value.version
        instance["version"] = serder.LONG.encode(versionValue)
        itemUidValue = value.itemUid
        instance["itemUid"] = serder.STRING.encode(itemUidValue)
        itemExtIdValue = value.itemExtId
        instance["itemExtId"] = serder.STRING.encode(itemExtIdValue)
        authorValue = value.author
        instance["author"] = serder.STRING.encode(authorValue)
        from netbluemind.core.container.model.ChangeLogEntryType import ChangeLogEntryType
        from netbluemind.core.container.model.ChangeLogEntryType import __ChangeLogEntryTypeSerDer__
        typeValue = value.type
        instance["type"] = __ChangeLogEntryTypeSerDer__().encode(typeValue)
        dateValue = value.date
        instance["date"] = serder.DATE.encode(dateValue)
        originValue = value.origin
        instance["origin"] = serder.STRING.encode(originValue)
        internalIdValue = value.internalId
        instance["internalId"] = serder.LONG.encode(internalIdValue)
        weightSeedValue = value.weightSeed
        instance["weightSeed"] = serder.LONG.encode(weightSeedValue)
        return instance




#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class IMMessage :
    def __init__( self):
        self.timestamp = None
        self.from_ = None
        self.to = None
        self.body = None
        pass

class __IMMessageSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = IMMessage()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        timestampValue = value['timestamp']
        instance.timestamp = serder.DATE.parse(timestampValue)
        from_Value = value['from']
        instance.from_ = serder.STRING.parse(from_Value)
        toValue = value['to']
        instance.to = serder.STRING.parse(toValue)
        bodyValue = value['body']
        instance.body = serder.STRING.parse(bodyValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        timestampValue = value.timestamp
        instance["timestamp"] = serder.DATE.encode(timestampValue)
        from_Value = value.from_
        instance["from"] = serder.STRING.encode(from_Value)
        toValue = value.to
        instance["to"] = serder.STRING.encode(toValue)
        bodyValue = value.body
        instance["body"] = serder.STRING.encode(bodyValue)
        return instance




import sys
from setuptools import setup, find_packages

install_requires = ['requests']
if sys.version_info < (3, 4):
    install_requires.append('enum34')

setup(
    name = 'netbluemind4',
    packages = find_packages(),
    version = '4.1.57000',
    description = 'Automatically generated client for BlueMind >= 4 REST API. Check netbluemind for older releases',
    author = 'BlueMind team',
    author_email = 'contact@bluemind.net',
    url = 'http://git.blue-mind.net/bluemind/',
    keywords = ['bluemind', 'rest', 'api', 'mail', 'groupware'],
    classifiers = [
        'Development Status :: 5 - Production/Stable',
        'Intended Audience :: Developers',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
    ],
    install_requires=install_requires
)



#
#  BEGIN LICENSE
#  Copyright (c) Blue Mind SAS, 2012-2016
# 
#  This file is part of BlueMind. BlueMind is a messaging and collaborative
#  solution.
# 
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of either the GNU Affero General Public License as
#  published by the Free Software Foundation (version 3 of the License).
# 
# 
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# 
#  See LICENSE.txt
#  END LICENSE
#
import requests
from netbluemind.python import serder

class DirEntryQueryOrder :
    def __init__( self):
        self.by = None
        self.dir = None
        pass

class __DirEntryQueryOrderSerDer__:
    def __init__( self ):
        pass

    def parse(self, value):
        if(value == None):
            return None
        instance = DirEntryQueryOrder()

        self.parseInternal(value, instance)
        return instance

    def parseInternal(self, value, instance):
        from netbluemind.directory.api.DirEntryQueryOrderBy import DirEntryQueryOrderBy
        from netbluemind.directory.api.DirEntryQueryOrderBy import __DirEntryQueryOrderBySerDer__
        byValue = value['by']
        instance.by = __DirEntryQueryOrderBySerDer__().parse(byValue)
        from netbluemind.directory.api.DirEntryQueryDir import DirEntryQueryDir
        from netbluemind.directory.api.DirEntryQueryDir import __DirEntryQueryDirSerDer__
        dirValue = value['dir']
        instance.dir = __DirEntryQueryDirSerDer__().parse(dirValue)
        return instance

    def encode(self, value):
        if(value == None):
            return None
        instance = dict()
        self.encodeInternal(value,instance)
        return instance

    def encodeInternal(self, value, instance):

        from netbluemind.directory.api.DirEntryQueryOrderBy import DirEntryQueryOrderBy
        from netbluemind.directory.api.DirEntryQueryOrderBy import __DirEntryQueryOrderBySerDer__
        byValue = value.by
        instance["by"] = __DirEntryQueryOrderBySerDer__().encode(byValue)
        from netbluemind.directory.api.DirEntryQueryDir import DirEntryQueryDir
        from netbluemind.directory.api.DirEntryQueryDir import __DirEntryQueryDirSerDer__
        dirValue = value.dir
        instance["dir"] = __DirEntryQueryDirSerDer__().encode(dirValue)
        return instance

